mgJsComponentHandler.addDefaultComponent('mg-carousel', {
    template: '#t-mg-carousel',
    props: [
        'component_id',
        'component_namespace',
        'component_index'
    ],
    data: function () {
        return {
            items: {},
            areItems: true,
            loading_state: true,
            allowedIdsToReload: [
                'relatedProducts',
                'recommendedProducts'
            ],
            isAnimate: false,
            cartItemSelector: null,
            cartSummarySelector: null,
            moveArrow: false,

            sliderClicked: false,
            sliderClickedElement: false,
            sliderXPosition: 0,
            sliderClickStartPosition: false,
        }
    },
    created: function () {

        var self = this;
        self.$nextTick(function () {
            self.loadAjaxData();
        });
    },
    methods: {
        loadAjaxData: function () {
            var self = this;

            self.loading_state = true;


            var requestParams = {
                loadData: self.component_id,
                namespace: self.component_namespace,
                index: self.component_index
            };

            var response = mgPageControler.vueLoader.vloadData(requestParams);

            return response.done(function (data) {
                self.cartItemSelector = data.data.rawData.customData.cartItemSelector;
                self.cartSummarySelector = data.data.rawData.customData.cartSummarySelector;
                self.items = data.data.rawData.items;


                var listOfObjects = Object.keys(self.items).map(function (key) {
                    return self.items[key]
                });
                self.items = listOfObjects;

                if(self.items.length < 1)
                {
                    self.areItems = false;
                }
                self.appendCartLoader();
                self.isMoveArrow();
                self.loading_state = false;
            }).fail(function () {
                self.loading_state = false;

            });
        },
        addToCart: function (productId, event) {
            var self = this;
            self.loading_state = true;

            event.preventDefault();

            var addToCartWhmcsUrl = "cart.php?a=add&skipconfig=true&pid=" + productId;
            $.get(addToCartWhmcsUrl).done(function (data) {
                self.addToCartContinue(productId, event);
            }).fail(function (data) {
                self.addToCartContinue(productId, event);
            });
        },
        addToCartContinue: function(productId, event)
        {
            var self = this;
            var requestParams = {
                loadData: self.component_id,
                namespace: self.component_namespace,
                index: self.component_index,
                crossSellerAction: 'addToCart',
                productId: productId,
            };

            self.toggleCartLoader(true);
            var response = mgPageControler.vueLoader.vloadData(requestParams);



            response.done(function (data) {
                var url = "cart.php?a=view"; //hardcoded but it will be always the same URI
                var request = $.get(url, function (data) {
                    $(document).find(self.cartItemSelector).replaceWith($(data).find(self.cartItemSelector));
                    if (self.cartSummarySelector !== null && (self.urlParams().a === 'view' || self.urlParams().a === 'checkout')) { //lagom use checkout page..
                        // $(document).find(self.cartSummarySelector).replaceWith($(data).find(self.cartSummarySelector));
                        $(document).find(self.cartSummarySelector).html($(data).find(self.cartSummarySelector).html());
                    }
                    self.toggleCartLoader();
                });
                $.each(mgPageControler.vueLoader.$children, function (key, value) {
                    if (self.allowedIdsToReload.indexOf(value.component_id) !== -1) {
                        value.loadAjaxData();
                    }
                });
            });

            response.fail(function (data) {
                self.loadAjaxData();
                self.toggleCartLoader();
            });
        },
        appendCartLoader: function () {
            var self = this;

            if ($('#crossSeller').length > 0) {
                return;
            }
            var loader = '<div id="crossSeller" style="display: none;"><div class="lu-preloader-container lu-preloader-container--full-screen lu-preloader-container--overlay" ><div class="lu-preloader lu-preloader--sm"></div></div>';
            $(document).find(self.cartItemSelector).closest('form').append(loader);
        },
        toggleCartLoader: function (show) {
            var self = this;
            var form = $(document).find(self.cartItemSelector).closest('form');
            var loader = $('#crossSeller').children('.lu-preloader-container');

            var height = form.height();
            loader.css('min-height', height + "px");
            if (form.length) {
                var offsetTop = form[0].offsetTop;
                loader.css('top', offsetTop + "px");
            }
            if (show) {
                $('#crossSeller').show();
                return;
            }
            $('#crossSeller').hide();
        },
        urlParams: function () { //przerobic to jeszcze
            var urlParams;
            (window.onpopstate = function () {
                var match,
                    pl = /\+/g,  // Regex for replacing addition symbol with a space
                    search = /([^&=]+)=?([^&]*)/g,
                    decode = function (s) {
                        return decodeURIComponent(s.replace(pl, " "));
                    },
                    query = window.location.search.substring(1);

                urlParams = {};
                while (match = search.exec(query))
                    urlParams[decode(match[1])] = decode(match[2]);
            })();
            return urlParams;
        },
        isMoveArrow: function () {
            this.moveArrow = this.items.length > 2 ? true : false;
        },
        slideInfoShow: function () {

            var widget = $(event.target).find('.widget-body');
            if(widget.is(':animated'))
            {
                return;
            }
            if (parseInt(widget.css("top")) < 0) {
                return;
            }
            widget.find(('.info')).css('visibility', 'visible')
            widget.animate({
                top: "+=" + (parseInt(widget.css("top")) - 100) + "px"
            }, 500);
        },
        slideInfoHide: function () {
            var widget = $(event.target).find('.widget-body');
            widget.animate({
                top: "0px"
            }, 500, function () {
                widget.find(('.info')).css('visibility', 'hidden')
            });

        },

        hasItemsLeft: function(allowedPx, translateX, actual)
        {
            return actual < 0;
        },
        hasItemsRight: function(allowedPx, translateX, actual)
        {
            return allowedPx <= translateX;
        },
        moveCarousel: function (px,event) {

            var wrapper = $(event.target.closest('.lSSlideWrapper')).find(".lSSlide.lsGrab");
            var exampleItem = wrapper.find('.additional-product-widget:first');

            var margin = parseInt(exampleItem[0].offsetLeft) * 2;
            var width = exampleItem.width();
            width =  px > 0 ? margin + width : -margin + (width * -1) ;

            var actual = parseInt($(wrapper).css('transform').split(',')[4]);
            var translateX = actual + width;
            var allowedPx = width * (this.items.length -2);

            if(px < 0 && !this.hasItemsRight(allowedPx, translateX, actual))
            {
                return;
            }
            if(px > 0 && !this.hasItemsLeft(allowedPx, translateX, actual))
            {
                return;
            }
            self = this;
            self.isAnimate = true;
            $(wrapper).css('transform', 'translate3d(' + (translateX) + 'px, 0px, 0px)');

            setTimeout(function()
            {
                self.isAnimate = false;
            }, 300);

        },


        // moveSlider: function (event) {
        //
        //     if (this.sliderClicked == false || this.sliderClickedElement == false || this.sliderClickStartPosition == false) {
        //         return;
        //     }
        //     var move = event.clientX - this.sliderClickStartPosition;
        //     var actual = parseInt($(this.sliderClickedElement).css('transform').split(',')[4]);
        //     var move = actual + move;
        //     $(this.sliderClickedElement).css('padding-bottom', '0%');
        //     $(this.sliderClickedElement).css('transform', 'translate3d(' + move + 'px, 0px, 0px)');
        //
        //
        // },
        // mouseDownAction: function (event) {
        //
        //     this.sliderClicked = true;
        //     var el = $(event.target).parents('.lsGrab:first');
        //
        //     this.sliderClickStartPosition = event.clientX;
        //     this.sliderClickedElement = el;
        // },
        // mouseUpAction: function () {
        //     this.sliderClicked = false;
        //     this.sliderClickedElement = false;
        //     this.sliderClickStartPosition = false;
        // },
    }
});

